pub struct DataBasedSwitchState {
pub id: Option<String>,
pub name: String,
pub state_data_filter: Option<StateDataFilter>,
pub timeouts: Option<DataBasedSwitchStateTimeouts>,
pub data_conditions: Vec<DataCondition>,
pub on_errors: Option<Vec<Error>>,
pub default_condition: DefaultConditionDef,
pub compensated_by: Option<String>,
pub used_for_compensation: bool,
pub metadata: Option<Metadata>,
}Expand description
Permits transitions to other states based on data conditions
Fields
id: Option<String>Unique State id
name: StringState name
state_data_filter: Option<StateDataFilter>State data filter
timeouts: Option<DataBasedSwitchStateTimeouts>State specific timeouts
data_conditions: Vec<DataCondition>Defines conditions evaluated against state data
on_errors: Option<Vec<Error>>States error handling definitions
default_condition: DefaultConditionDefDefault transition of the workflow if there is no matching data conditions.
Can include a transition or end definition.
compensated_by: Option<String>Unique Name of a workflow state which is responsible for compensation of this state
used_for_compensation: boolIf true, this state is used to compensate another state. Default is false
metadata: Option<Metadata>State metadata