pub struct EventDataFilter {
pub use_data: bool,
pub data: Option<String>,
pub to_state_data: Option<String>,
}Expand description
Event data filter
Fields
use_data: boolIf set to false, event payload is not added/merged to state data.
In this case data and to_state_data should be ignored. Default is true.
data: Option<String>Workflow expression that filters the received event payload (default: ${ . })
to_state_data: Option<String>Workflow expression that selects a state data element to which the filtered event should be added/merged into.
If not specified, denotes, the top-level state data element.