Struct WorkflowInstance

pub struct WorkflowInstance {
    pub id: String,
    pub workflow_identifier: Identifier,
    pub state: Option<String>,
    pub data: Map<String, Value>,
    pub terminated: bool,
}
Workflow instance container.

TODO expand

Fields

id: String

Workflow instance ID. Unique among all workflow instances.

workflow_identifier: Identifier

Workflow identifier.

state: Option<String>

Name of current workflow state, or None if workflow has completed.

data: Map<String, Value>

Workflow data (a JSON object), passed between states.

If state is None, this is the final workflow output.

terminated: bool

Whether workflow has terminated prematurely.

Implementations

Source

impl WorkflowInstance

pub fn for_definition( definition: &WorkflowDefinition, input: Option<Map<String, Value>>, ) -> Self

Generates a new workflow instance from a WorkflowDefinition.

The instance will have a new, randomly-generated id, will start at the workflow’s start state with the provided workflow input (or an empty JSON object if no initial input is provided).

pub fn for_workflow_identifier<I>( identifier: I, state: Option<String>, data: Option<Map<String, Value>>, ) -> Self
where I: Into<Identifier>,

Generates a new workflow instance for a workflow identified via its Identifier.

The instance will have a new, randomly-generated id, will point to the given state and contain the given data (or an empty JSON object if no data is provided).